@@ -30,15 +30,12 @@
 #undef minor
 #undef major
 
-#define POPPLER_VERSION "25.05.0"
-#define POPPLER_VERSION_MAJOR 25
-#define POPPLER_VERSION_MINOR 5
+#define POPPLER_VERSION "26.02.0"
+#define POPPLER_VERSION_MAJOR 26
+#define POPPLER_VERSION_MINOR 2
 #define POPPLER_VERSION_MICRO 0
 
-namespace Poppler
-{
-
-namespace Version
+namespace Poppler::Version
 {
 
 /**
@@ -63,6 +60,4 @@ POPPLER_QT6_EXPORT unsigned int micro();
 
 }
 
-}
-
 #endif
